:
# NAME:
#	setup.sh - setup the environment for us.
#	
# DESCRIPTION:
#	This is an example of how we setup a working environment for
#	frobbing the DNS via automagic means.
#	We arrange for rc.sh(8) to stop processing if anything fails.
#	We ensure we have a private temp directory and arrange to
#	clean it up when we are done - provided all goes well.
#	We also change the working directory to the tree reserved for
#	us.
#
# FILES:
#	/var/cron/named		default working directory
#	
# AUTHOR:
#	Simon J. Gerraty <sjg@crufty.net>

# RCSid:
#	$Id: setup.sh,v 1.12 2016/04/11 00:44:11 sjg Exp $
#
#	@(#)Copyright (c) 1997-2001 Simon J. Gerraty.
#	All rights reserved.
#	
#	This software is the property of Simon J. Gerraty.
#	It may be used only in accordance with the conditions outlined
#	in the accompanying LICENSE file. If your distribution does
#	not contain a LICENSE file, then you have no rights to use
#	this software and should contact sales@crufty.net to obtain a
#	licensed distribution.
#	
#	This software is provided "AS IS" in the hope that it will be
#	of use.  Since it is not possible to anticipate all possible
#	use of this software, there is absolutely NO WARRANTY.
#
#	Please forward bug reports and fixes to help@crufty.net
#

RC_D=${RC_D:-/etc/rc_d}
SHARE=${SHARE:-/usr/local/share}
DNSMAGIC=${DNSMAGIC:-$SHARE/dns}

# first we want rc.sh to bail out if anything fails.
ErrExit=Exit

# handy to be able to debug stuff
. $RC_D/debug.sh

DebugOn setup

# for cleaning up
$_ATEXIT_SH . $RC_D/atexit.sh
case "$_TEMP_SH" in
"") # looks like /etc/rc_d/redirect.sh not being used
        $_TEMP_SH . $RC_D/temp.sh
        case "$TEMP" in
	*/tmp/?*)			# be careful
                atexit "[ x\${ExitStatus:-1} = x0 ] && rm -rf $TEMP";;
	esac
        ;;
esac
# make sure these are in our path
add_path $DNSMAGIC/bin
add_path $DNSMAGIC/cron.d
add_path $SHARE/bin

# want this set correctly
MAKE=${MAKE:-`Which bmake`}
MAKE=${MAKE:-make}

# share this where possible
ND_DATA=${TMP:-/tmp}/nd_data$$

WORK_DIR=${WORK_DIR:-/var/cron/named}
cd $WORK_DIR || Exit 1

export MAKE WORK_DIR PATH RC_D ND_DATA
# keep a copy of the report in the work dir
REPORT_TO=${REPORT_TO:-"file mail"}
export REPORT REPORT_TO
